********
Glossary
********

.. glossary::

    add_test
        :term:`CMake` function used to add tests to the project, which will
        be run by :term:`CTest`.

        .. seealso:: https://cmake.org/cmake/help/latest/command/add_test.html

    CMake
        CMake is a compilation configuration platform that manages the build
        process in an operating system and in a compiler-independent manner.

        .. seealso:: https://cmake.org/overview/

    CTest
        CTest is an executable that comes with :term:`CMake` which handles
        running the tests.

        .. seealso:: https://cmake.org/cmake/help/latest/manual/ctest.1.html

    GTest
        Google Test is a testing and mocking framework for C++.

        .. seealso:: http://google.github.io/googletest/

    find_package
        :term:`CMake` function is used to provide locations of package
        dependencies to build a project.

        .. seealso:: https://cmake.org/cmake/help/latest/command/find_package.html

    fixture
        A :term:`Pytest` fixture provides a fixed setup and teardown for tests.

        .. seealso:: https://docs.pytest.org/en/latest/explanation/fixtures.html

    nanobind
        Nanobind is a fast, minimalistic C++ library designed to create Python
        bindings for C++ code.

        .. seealso:: https://nanobind.readthedocs.io/en/latest/index.html

    parametrizing tests
        Parameterized tests in :term:`Pytest` enable the execution of a single test function
        with multiple sets of input parameters, facilitating the evaluation of different
        test cases within a unified test structure.

        .. seealso:: https://docs.pytest.org/en/stable/how-to/parametrize.html

    regular expression
        A regular expression is a sequence of characters that defines a search pattern,
        typically used for pattern matching and manipulation within strings.

        .. seealso:: https://en.wikipedia.org/wiki/Regular_expression

    Pip
        Pip is a package-management system written for Python.

        .. seealso:: https://pip.pypa.io/en/stable/

    Pytest
        Python testing framework.

        .. seealso:: https://docs.pytest.org/
